Name:           python3-ncclient
Version:        0.6.12
Release:        3%{?dist}
Summary:        Python library for the NETCONF protocol

License:        ASL 2.0
URL:            https://github.com/ncclient/ncclient/
Source0:        %{url}/archive/v%{version}/ncclient-%{version}.tar.gz

# The version of Paramiko for Python 3 in EPEL7 does not contain ED25519
# support; allow ncclient to fail gracefully in its absence
Patch0:         ncclient-0.6.10-support-paramiko-without-ED25519.patch

BuildArch:      noarch

BuildRequires:  python%{python3_pkgversion}-devel

# requirements.txt:
BuildRequires:  python%{python3_pkgversion}-setuptools >= 0.6
BuildRequires:  python%{python3_pkgversion}-paramiko >= 1.15.0
BuildRequires:  python%{python3_pkgversion}-lxml >= 3.3.0
BuildRequires:  python%{python3_pkgversion}-six

# requirements-test.txt:
BuildRequires:  python%{python3_pkgversion}-pytest-runner
BuildRequires:  python%{python3_pkgversion}-pytest-cov
# We are not going to run documentation build tests or linting tests, so we do
# not need sphinx or flake8 here.

%global common_description %{expand:
ncclient is a Python library that facilitates client-side scripting
and application development around the NETCONF protocol. ncclient was
developed by Shikar Bhushan.net). It is now maintained by Leonidas Poulopoulos
(@leopoul) and Einar Nilsen-Nygaard (@einarnn).

Docs: http://ncclient.readthedocs.org

PyPI: https://pypi.python.org/pypi/ncclient}

%description %{common_description}


# This is an EPEL7-only package; the conditional allows us to process the spec
# file on other distros (e.g. Fedora) without encountering “package
# python3-ncclient already exists”
%if %{python3_pkgversion} != 3
%package -n python%{python3_pkgversion}-ncclient
Summary:        %{summary}

%{?python_provide:%python_provide python%{python3_pkgversion}-ncclient}

# requirements.txt:
Requires:       python%{python3_pkgversion}-setuptools >= 0.6
Requires:       python%{python3_pkgversion}-paramiko >= 1.15.0
Requires:       python%{python3_pkgversion}-lxml >= 3.3.0
Requires:       python%{python3_pkgversion}-six

%description -n python%{python3_pkgversion}-ncclient %{common_description}
%endif


%package doc
Summary:        Documentation and examples for %{name}

BuildRequires:  make
# docs/requirements.txt
# The upstream requirement is sphinx >= 3.2.0; we have only 1.2.3 on EPEL7, so
# we cannot build the HTML documentation.

%description doc
The %{name}-doc package contains detailed documentation and examples
for %{name}.


%prep
%autosetup -n ncclient-%{version} -p1

# Fix shebangs in examples
find examples -type f |
  while read -r fn
  do
    if head -n 1 "${fn}" |
      grep -E '^#![[:blank:]]*/usr/bin/env[[:blank:]]+python[[:digit:].]*$' \
          >/dev/null
    then
      sed -r -i \
          '1{s|^#![[:blank:]]*/usr/bin/env[[:blank:]]+python[[:digit:].]*$|'\
'#!%{__python3}|}' "${fn}"
    fi
  done

# The version of paramiko we have available does not provide ED25519 support:
sed -r -i 's/, paramiko\.Ed25519Key//' test/unit/transport/test_ssh.py


%build
%py3_build
# Sphinx is too old to build the HTML documentation.


%install
%py3_install


%check
%{__python3} -m pytest

 
%if %{python3_pkgversion} != 3
%files -n python%{python3_pkgversion}-ncclient
%else
%files
%endif
%license LICENSE
%{python3_sitelib}/ncclient
%{python3_sitelib}/ncclient-%{version}-py%{python3_version}.egg-info


%files doc
%license LICENSE
%doc Changelog
%doc NOTICE
%doc README.md
%doc README.rst
# Sphinx is too old to build the HTML documentation.
%doc examples


%changelog
* Tue Feb 01 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.6.12-3
- Add missing runtime dependencies

* Sat Sep 18 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.6.12-2
- Reduce spec file macro indirection
- Add missing python_provide macro

* Sun May 30 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.6.12-1
- Update to 0.6.12
- Drop upstreamed patches

* Tue Mar 23 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.6.10-1
- New Python-3-only EPEL7 package backported from python-ncclient-0.6.10-2 in
  Fedora 35
